Re-exports
pub use hyper;pub use tower_service;
Modules
Structs
- Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Client
- A wrapper for hyper’s
Clienttype providing a simpler interface - Client
Builder - A builder for
Client - Connect
Error - Http
Connection - A wrapper around
tokio::net::TcpStream - Http
Connector - A simple HTTP connector
- Hyper
Client - A Client to make outgoing HTTP requests.
- Hyper
Client Builder - A builder to configure a new
Client. - Hyper
Connector Adapter - An adapter that given
T: hyper::client::connect::ConnectimplementsNetworkConnector - Incoming
- A stream of
Bytes, used when receiving bodies from the network. - Method
- The Request Method (VERB)
- Network
Connection - A boxed network connection
- Request
Body - This is an implementation of
hyper::body::Bodyfor use with HTTPRequests. - Request
Builder - An HTTP request builder
- Shared
Body - This is an implementation of
hyper::body::Bodyfor use with HTTPRequests. - Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Tokio
Executor - The default executor to use with the native hyper client.
- Uri
- The URI component of a request.
- Version
- Represents a version of the HTTP spec.
Enums
Traits
- Body
- Trait representing a streaming body of a Request or Response.
- Buf
- Read bytes from a buffer.
- Network
Connector - Network connector trait with type erasure
Functions
- aggregate
- Collects all of the data frames from this body into a
Buf. - to_
bytes - Collects all of the data frames from this body into
Bytes.