aggregate

Function aggregate 

pub async fn aggregate<T>(body: T) -> Result<impl Buf, T::Error>
where T: Body,
Collects all of the data frames from this body into a Buf.

As opposed to to_bytes(), this function avoids copying the data and is useful when you don’t need a contiguous slice of data.