pub struct ClientBuilder(/* private fields */);Expand description
A builder for Client
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
pub fn new() -> Self
Sourcepub fn from_hyper_client_builder(inner: HyperClientBuilder) -> Self
pub fn from_hyper_client_builder(inner: HyperClientBuilder) -> Self
Create a builder with a configured instance of HyperClientBuilder.
Sourcepub fn pool_max_idle_per_host(&mut self, max_idle: usize) -> &mut Self
pub fn pool_max_idle_per_host(&mut self, max_idle: usize) -> &mut Self
Sets the maximum idle connection per host allowed in the pool.
Default is usize::MAX (no limit).
Sourcepub fn pool_idle_timeout(&mut self, val: Option<Duration>) -> &mut Self
pub fn pool_idle_timeout(&mut self, val: Option<Duration>) -> &mut Self
Set an optional timeout for idle sockets being kept-alive.
Pass None to disable timeout.
Default is 90 seconds.
Sourcepub fn http2_only(&mut self, val: bool) -> &mut Self
pub fn http2_only(&mut self, val: bool) -> &mut Self
Set whether the connection must use HTTP/2.
Note that setting this to true prevents HTTP/1 from being allowed.
Default is false.
Sourcepub fn build<C: NetworkConnector>(&self, connector: C) -> Client
pub fn build<C: NetworkConnector>(&self, connector: C) -> Client
Combine the configuration of this builder with a connector to create a
Client.