Crate simple_hyper_client

Crate simple_hyper_client 

Re-exports

pub use hyper;
pub use tower_service;

Modules

blocking
This module provides a blocking interface on top of hyper’s HTTP client.
compat

Structs

Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
Client
A wrapper for hyper’s Client type providing a simpler interface
ClientBuilder
A builder for Client
ConnectError
HttpConnection
A wrapper around tokio::net::TcpStream
HttpConnector
A simple HTTP connector
HyperClient
A Client to make outgoing HTTP requests.
HyperClientBuilder
A builder to configure a new Client.
HyperConnectorAdapter
An adapter that given T: hyper::client::connect::Connect implements NetworkConnector
Incoming
A stream of Bytes, used when receiving bodies from the network.
Method
The Request Method (VERB)
NetworkConnection
A boxed network connection
RequestBody
This is an implementation of hyper::body::Body for use with HTTP Requests.
RequestBuilder
An HTTP request builder
SharedBody
This is an implementation of hyper::body::Body for use with HTTP Requests.
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
TokioExecutor
The default executor to use with the native hyper client.
Uri
The URI component of a request.
Version
Represents a version of the HTTP spec.

Enums

Error

Traits

Body
Trait representing a streaming body of a Request or Response.
Buf
Read bytes from a buffer.
NetworkConnector
Network connector trait with type erasure

Functions

aggregate
Collects all of the data frames from this body into a Buf.
to_bytes
Collects all of the data frames from this body into Bytes.

Type Aliases

HyperClientError
Request
Response